@@ -5,12 +5,10 @@
 #' @inheritParams bhl_getcollections
 #' @examples \dontrun{
 #' bhl_getpartbibtex(1000)
-#' bhl_getpartbibtex(1000, 'xml')
 #' bhl_getpartbibtex(1000, 'json')
 #' }
-
-bhl_getpartbibtex <- function(partid, as = "list", key = NULL, ...)
-{
-  args <- bhlc(list(op = "GetPartBibTex", apikey = check_key(key), format = as_f(as), partid=partid))
+bhl_getpartbibtex <- function(partid, as = "list", key = NULL, ...) {
+  args <- bhlc(list(op = "GetPartBibTex", apikey = check_key(key),
+                    format = as_f(as), partid = partid))
   bhl_GET(as, args, ...)
 }
