@@ -13,12 +13,12 @@
 #' @examples \dontrun{
 #' bhl_namecount(startdate = '12/25/2009', enddate = '12/27/2009')
 #' bhl_namecount(startdate = '10/15/2009', enddate = '10/17/2009', as='json')
-#' bhl_namecount(startdate = '10/15/2009', enddate = '10/17/2009', as='xml')
 #' }
+bhl_namecount <- function(startdate = NULL, enddate = NULL, as='table',
+                          key = NULL, ...) {
 
-bhl_namecount <- function(startdate = NULL, enddate = NULL, as='table', key = NULL, ...)
-{
-  args <- bhlc(list(op = "NameCount", apikey = check_key(key), format = as_f(as),
-                       startdate=startdate, enddate=enddate))
+  args <- bhlc(list(op = "NameCount", apikey = check_key(key),
+                    format = as_f(as), startdate = startdate,
+                    enddate = enddate))
   bhl_GET(as, args, ...)
 }
