@@ -8,8 +8,8 @@ test_that("bhl_authorsearch returns", {
 	uu <- bhl_authorsearch(name='dimmock', as = "list")
 
 	# correct classes
-	expect_is(tt$data, "data.frame")
-	expect_is(tt$data$CreatorID, "integer")
+	expect_is(tt, "data.frame")
+	expect_is(tt$CreatorID, "integer")
 
 	expect_is(uu, "list")
 	expect_is(uu$Status, "character")
@@ -20,6 +20,6 @@ test_that("bhl_authorsearch returns", {
 	expect_is(bhl_authorsearch(name='dimmock', as="xml"), "character")
 
 	# correct dimensions
-  expect_equal(NCOL(tt$data), 12)
+  expect_equal(NCOL(tt), 12)
   expect_equal(length(uu$Status), 1)
 })
