@@ -8,16 +8,16 @@ test_that("bhl_getitemmetadata returns the correct class", {
 	uu <- bhl_getitemmetadata('16800', TRUE, as='xml')
 	vv <- bhl_getitemmetadata('16800', TRUE, as='json')
 
-  expect_is(tt$data, "data.frame")
+  expect_is(tt, "data.frame")
 
   expect_is(uu, "character")
-  expect_is(xmlParse(uu), "XMLInternalDocument")
+  expect_is(xml2::read_xml(uu), "xml_document")
 
   expect_is(vv, "character")
-  expect_is(fromJSON(vv), "list")
+  expect_is(jsonlite::fromJSON(vv), "list")
 
-  expect_equal(NCOL(tt$data), 31)
+  expect_equal(NCOL(tt), 31)
   expect_equal(length(uu), 1)
   expect_equal(length(vv), 1)
-  expect_equal(length(fromJSON(vv)), 3)
+  expect_equal(length(jsonlite::fromJSON(vv)), 3)
 })
